(annotation)=
# Annotation

This section contains tutorials showing how to annotate images and videos using the napari points, labels, or shapes layers.

* [Annotating videos with napari](annotate_points)
